Anomaly Component
add_anomaly(x, ...)# S3 method for issm.component
add_anomaly(x, time = NULL, delta = 0, ratio = 0.5, ...)
An object of class issm.component updated with the anomaly component.
an object of class issm.component or other supported class.
additional parameters.
the numeric index of when the anomaly occurs. If NULL, a random time will be chosen.
the autoregressive component determining the type of anomaly. A value of zero results in an additive outlier, a value of 1 in a level shift and anything in between a temporary change with a half life of -log(2)/log(delta).
the anomaly to series ratio at the time it occurs. For instance, a value of 1 means that the anomaly will jump by 100 percent compared to the data series.