add_polynomial: Polynomial Trend Component

add_polynomial.issm.componentR Documentation

Polynomial Trend Component

Description

Polynomial Trend Component

Usage

## S3 method for class 'issm.component'
add_polynomial(
  object,
  order = 1,
  alpha = 0.1,
  beta = 0.01,
  phi = 1,
  l0 = 100,
  b0 = 1,
  ...
)

Arguments

object

an object of class issm.component or other supported class.

order

the order of the polynomial (min 1 and max 2).

alpha

the decay coefficient on the error of the level.

beta

the decay coefficient on the error of the slope.

phi

dampening parameter for the slope.

l0

initial level.

b0

initial slope.

...

additional parameters.

Value

An object of class issm.component updated with the polynomial trend component.


tsaux documentation built on April 4, 2026, 9:06 a.m.