add_seasonal: Seasonal Trend Component

add_seasonal.issm.componentR Documentation

Seasonal Trend Component

Description

Seasonal Trend Component

Usage

## S3 method for class 'issm.component'
add_seasonal(
  object,
  frequency = 12,
  gamma = 0.01,
  s0 = NULL,
  init_harmonics = frequency/2,
  normalized_seasonality = TRUE,
  init_scale = 1,
  ...
)

Arguments

object

an object of class issm.component or other supported class.

frequency

seasonal frequency.

gamma

the decay coefficient on the error of the seasonal component

s0

a vector of length frequency - 1 for the initial seasonal component.

init_harmonics

number of harmonics to initialize s0 when this is not provided.

normalized_seasonality

whether normalize the seasonal component based on the method of Roberts and McKenzie. This is applied only to a single seasonal frequency.

init_scale

the scaling multiplier for s0 (when this is not provided).

...

additional parameters.

Value

An object of class issm.component updated with the seasonal component.


tsaux documentation built on April 4, 2026, 9:06 a.m.