Learn R Programming

tsaux (version 1.0.0)

calendar_eom: End of Month Date

Description

Returns the last day of the month from a Date within the month.

Usage

calendar_eom(date, ...)

Value

Date object

Arguments

date

a Date vector

...

not used

Author

Alexios Galanos

Details

Given a Date (such as 2019-01-02), will return the last Date within that year month.