Learn R Programming

tsaux (version 1.0.0)

calendar_eoq: End of Quarter Date

Description

Returns the last day of the quarter from a Date.

Usage

calendar_eoq(date, ...)

Value

Date object

Arguments

date

a Date vector

...

not used

Author

Alexios Galanos

Details

Given a date (such as 2019-01-02), will return the last date within that year quarter.