powered by
Creates a matrix of seasonal dummies.
seasonal_dummies(y = NULL, n = nrow(y), seasons = 12)
Either a matrix (if y is missing or y is not an xts vector) or an xts matrix (when y is an xts vector).
optional data series.
if y is missing, then the length of the series is required.
number of seasons in a cycle.
Alexios Galanos
Generates seasons-1 dummy variables.
head(seasonal_dummies(n=100, seasons=12))
Run the code above in your browser using DataLab