Learn R Programming

tsaux (version 1.0.0)

seasonality_test: Simple Seasonality Test

Description

Checks for the presence of seasonality based on the QS test of Gomez and Maravall (1996).

Usage

seasonality_test(x, frequency = NULL)

Value

Logical.

Arguments

x

an (xts) vector (usually of a stationary series).

frequency

overrides any frequency automatically identified in the index of x.

Author

Alexios Galanos

Details

Given the identified frequency of the xts vector (using the sampling_frequency), the function checks for seasonality at that frequency. The frequency can be overridden by directly supplying a frequency argument, in which case y does not need to be a xts vector.

References

Gomez1995tsaux