tsdecompose: State Decomposition

tsdecompose.issm.componentR Documentation

State Decomposition

Description

State Decomposition

Usage

## S3 method for class 'issm.component'
tsdecompose(object, ...)

Arguments

object

an object of class issm.component or other supported class.

...

additional parameters.

Details

Creates a simplified decomposition of the states and aligns their time indices so that the sum up to the simulated component per period.

Value

A matrix of the simplified state decomposition.


tsmodels/tsaux documentation built on June 1, 2025, 10:19 p.m.