| add_polynomial.issm.component | R Documentation |
Polynomial Trend Component
## S3 method for class 'issm.component'
add_polynomial(
object,
order = 1,
alpha = 0.1,
beta = 0.01,
phi = 1,
l0 = 100,
b0 = 1,
...
)
object |
an object of class issm.component or other supported class. |
order |
the order of the polynomial (min 1 and max 2). |
alpha |
the decay coefficient on the error of the level. |
beta |
the decay coefficient on the error of the slope. |
phi |
dampening parameter for the slope. |
l0 |
initial level. |
b0 |
initial slope. |
... |
additional parameters. |
An object of class issm.component updated with the polynomial trend component.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.