Polynomial Trend Component
add_polynomial(x, ...)# S3 method for issm.component
add_polynomial(
x,
order = 1,
alpha = 0.1,
beta = 0.01,
phi = 1,
l0 = 100,
b0 = 1,
...
)
An object of class issm.component updated with the polynomial trend component.
an object of class issm.component or other supported class.
additional parameters.
the order of the polynomial (min 1 and max 2).
the decay coefficient on the error of the level.
the decay coefficient on the error of the slope.
dampening parameter for the slope.
initial level.
initial slope.