powered by
Returns the last day of the month from a Date within the month.
calendar_eom(date, ...)
Date object
a Date vector
not used
Alexios Galanos
Given a Date (such as 2019-01-02), will return the last Date within that year month.