powered by
Returns the last day of the quarter from a Date.
calendar_eoq(date, ...)
Date object
a Date vector
not used
Alexios Galanos
Given a date (such as 2019-01-02), will return the last date within that year quarter.