Checks for the presence of seasonality based on the QS test of Gomez and Maravall (1996).
seasonality_test(x, frequency = NULL)Logical.
an (xts) vector (usually of a stationary series).
overrides any frequency automatically identified in the index of x.
Alexios Galanos
Given the identified frequency of the xts vector (using the
sampling_frequency), the function checks for seasonality at
that frequency. The frequency can be overridden by directly supplying a
frequency argument, in which case y does not need to be a xts vector.
Gomez1995tsaux